summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmtextedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmtextedit.h')
-rw-r--r--kpovmodeler/pmtextedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmtextedit.h b/kpovmodeler/pmtextedit.h
index 96510257..9d90c68c 100644
--- a/kpovmodeler/pmtextedit.h
+++ b/kpovmodeler/pmtextedit.h
@@ -42,9 +42,9 @@ class PMTextEdit : public PMSolidObjectEdit
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMTextEdit with tqparent and name
*/
- PMTextEdit( TQWidget* tqparent, const char* name = 0 );
+ PMTextEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -42,9 +42,9 @@ class PMTextEdit : public PMSolidObjectEdit
public:
/**
- * Creates a PMTextEdit with tqparent and name
+ * Creates a PMTextEdit with parent and name
*/